@@ -3,14 +3,16 @@ from typing import Dict
 from pyPhases.storage.Storage import Storage
 from pyPhases.Data import Data, DataNotFound
 from pyPhases.Stage import Stage
+from pyPhases.Phase import Phase
 from pyPhases.decorator.ExportValidator import ExportValidator
 from pyPhases.util.Logger import classLogger, Logger, LogLevel
+from pyPhases.util.Optionizable import Optionizable
 
 class ConfigNotFoundException(Exception):
     pass
 
 @classLogger
-class Project:
+class Project(Optionizable):
     """
     Represents a whole project with several phases
 
@@ -46,6 +48,7 @@ class Project:
         self.registerDecorator(ExportValidator())
 
     def addStorage(self, storage):
+        self.logDebug("Add StorageHandler: " + type(storage).__name__)
         self.dataStorage.append(storage)
 
     def registerDecorator(self, decorator):
@@ -82,7 +85,7 @@ class Project:
         self.logDebug("Get Exporter For: " + type(instance).__name__)
         return self.getExporterForType(type(instance))
 
-    def getExporterForType(self, theType, storage: Storage = None):
+    def getExporterForType(self, theType, storage: Storage = None, reinit = True):
         exporters = self.exporters
 
         if storage != None and storage.acceptedExporter != None:
@@ -92,7 +95,10 @@ class Project:
             self.logDebug("Check: " + type(exporter).__name__)
             if exporter.checkType(theType):
                 self.logDebug("Found exporter")
-                return exporter.reinit()
+                if reinit:
+                    return exporter.reinit()
+                else:
+                    return exporter
         return None
 
     def registerStream(self, dataName, expectedReturnType, options, version: str = "current"):
@@ -108,6 +114,19 @@ class Project:
         except Exception:
             raise Exception("No stream exporter found for this")
 
+    def getExporterAndId(self, dataName, expectedReturnType, options = {}, version: str = "current"):
+
+        dataObj = Data.getFromName(dataName)
+        dataObj.version = version
+        dataObj.setProject(self)
+        dataId = dataObj.getDataId()
+
+        try:
+            exporter = self.getExporterForType(expectedReturnType, reinit = False)
+            return exporter, dataId
+        except Exception:
+            raise Exception("No stream exporter found for this")
+
     def dataExists(self, data: Data):
         return data.getDataId() in self.registeredData
 
@@ -214,7 +233,7 @@ class Project:
 
             self.config[name] = config[name]
 
-    def addPhase(self, phase, stage: str = "", name: str = None):
+    def addPhase(self, phase, stage: str = "default", name: str = None):
         if (name != None):
             phase.name = name
 
@@ -230,20 +249,31 @@ class Project:
 
     def runAllStages(self):
         for stage in self.stages:
-            self.runStage(stage.name)
+            if stage.getOption("autorun"):
+                self.runStage(stage.name)
 
     def runStage(self, stageName):
         self.log("RUN stage " + stageName)
         for phase in self.phases[stageName]:
-            phase.run()
+            self.runPhase(phase)
 
-    def run(self, stageName=None):
-        if (stageName == None):
+    def runStageOrPhase(self, stageOrPhaseName):
+        if stageOrPhaseName in self.stages:
+            self.runStage(stageOrPhaseName)
+        else:
+            phase = self.getPhase(stageOrPhaseName)
+            self.runPhase(phase)
+
+    def run(self, stageOrPhaseName=None):
+        if (stageOrPhaseName == None):
             self.runAllStages()
         else:
-            self.runStage(stageName)
+            self.runStageOrPhase(stageOrPhaseName)
 
-    def getPhase(self, name: str):
+    def runPhase(self, phase: Phase):
+        phase.run()
+
+    def getPhase(self, name: str) -> Phase:
         return self.phaseMap[name]
 
     def getPhases(self):
