@@ -8,7 +8,8 @@ class FileStorage(Storage):
             file = open(self.getPath(path), "rb")
             return file.read()
         except FileNotFoundError:
-            raise DataNotFound("Data was not found:" + path)
+            self.logDebug("Data was not found: %s (%s)"%(path, self.getPath(path)))
+            raise DataNotFound("Data was not found: %s"%(path))
 
     def write(self, path, data):
         if isinstance(data, bytes):
