@@ -3,20 +3,20 @@ import os.path
 
 from ..util.Optionizable import Optionizable
 
-class DataNotFound(Exception):
-    pass
-
 class PermissionDenied(Exception):
     pass
 
 class Storage(Optionizable):
-    basePath: str
+    acceptedExporter = None
+    def __init__(self, options = {}):
+        if(not "basePath" in options):
+            options["basePath"] = "."
+        super(Storage, self).__init__(options)
 
-    def __init__(self, basePath="."):
-        self.basePath = basePath
 
     def getPath(self, path):
-        return os.path.normpath(self.basePath + '/' + path)
+        basePath = self.getOption("basePath")
+        return os.path.normpath(basePath + '/' + path)
 
     @abstractmethod
     def read(self, path):
