@@ -13,7 +13,7 @@ class Logger():
     verboseLevel: LogLevel = LogLevel.INFO
 
     @staticmethod
-    def log(msg, system=None, level=LogLevel.INFO):
+    def log(msg, system=None, level=LogLevel.INFO, end='\n'):
         if (system != None):
             msg = "[" + system + "] " + msg
 
@@ -23,7 +23,7 @@ class Logger():
             msg = u"\033[31;1;4m%s\033[0m" % (msg)
 
         if (Logger.verboseLevel.value <= level.value):
-            print(msg)
+            print(msg, end=end)
 
 
 def classLogger(class_):
@@ -44,8 +44,15 @@ def classLogger(class_):
         system = type(self).__name__
         Logger.log(msg, system, LogLevel.ERROR)
 
+    def logProgress(self, msg, current=0, max=100, level=LogLevel.INFO):
+        system = type(self).__name__
+        msg = "%s: %i/%i"%(msg, current, max)
+        end = "\n" if current >= max else "\r"
+        Logger.log(msg, system, level, end=end)
+
     class_.log = log
     class_.logDebug = logDebug
     class_.logWarning = logWarning
     class_.logError = logError
+    class_.logProgress = logProgress
     return class_
